pub struct DiagnosticBuilder<'d> { /* private fields */ }Implementations
Sourceimpl<'d> DiagnosticBuilder<'d>
impl<'d> DiagnosticBuilder<'d>
Sourcepub fn message(self, msg: impl Into<String>) -> DiagnosticBuilder<'d>
pub fn message(self, msg: impl Into<String>) -> DiagnosticBuilder<'d>
Provide custom detail for this diagnostic, rendered using the kind’s template.
Sourcepub fn suppression_range(self, range: TextRange) -> DiagnosticBuilder<'d>
pub fn suppression_range(self, range: TextRange) -> DiagnosticBuilder<'d>
Set the suppression range for this diagnostic.
The suppression range is used to suppress cascading errors. Errors whose display range falls within another error’s suppression range may be suppressed if the containing error has higher priority.
Typically set to the parent context span (e.g., enclosing tree).
pub fn fix( self, description: impl Into<String>, replacement: impl Into<String>, ) -> DiagnosticBuilder<'d>
pub fn hint(self, hint: impl Into<String>) -> DiagnosticBuilder<'d>
pub fn emit(self)