QueryInterpreter

Struct QueryInterpreter 

pub struct QueryInterpreter<'q, 'tree> { /* private fields */ }
Query interpreter that executes a compiled query against an AST.

Implementations

Source

impl<'q, 'tree> QueryInterpreter<'q, 'tree>

pub fn new( query: &'q CompiledQuery, cursor: TreeCursor<'tree>, source: &'tree str, ) -> Self

Creates a new interpreter.

The cursor should be positioned at the tree root.

pub fn with_exec_fuel(self, fuel: u32) -> Self

Set execution fuel limit.

pub fn with_recursion_fuel(self, fuel: u32) -> Self

Set recursion fuel limit.

pub fn run(self) -> Result<Value<'tree>, RuntimeError>

Run the query and return the result.

pub fn run_from(self, start: TransitionId) -> Result<Value<'tree>, RuntimeError>

Run the query from a specific transition and return the result.