BuildGraph

Struct BuildGraph 

pub struct BuildGraph<'src> { /* private fields */ }
Build-time graph for query compilation.

Nodes are stored in a flat vector, referenced by NodeId. Definitions map names to their entry points.

Implementations

Source

impl<'src> BuildGraph<'src>

pub fn new() -> Self

pub fn add_node(&mut self, node: BuildNode<'src>) -> NodeId

pub fn add_epsilon(&mut self) -> NodeId

pub fn clone_node_with_nav(&mut self, node_id: NodeId, nav: Nav) -> NodeId

Clone a node, creating a new node with the same matcher, effects, and ref_marker, but with the specified nav and copying the successors list.

pub fn add_matcher(&mut self, matcher: BuildMatcher<'src>) -> NodeId

pub fn add_definition(&mut self, name: &'src str, entry: NodeId)

pub fn definition(&self, name: &str) -> Option<NodeId>

pub fn definitions(&self) -> impl Iterator<Item = (&'src str, NodeId)> + '_

pub fn node(&self, id: NodeId) -> &BuildNode<'src>

pub fn node_mut(&mut self, id: NodeId) -> &mut BuildNode<'src>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn iter(&self) -> impl Iterator<Item = (NodeId, &BuildNode<'src>)>

pub fn connect(&mut self, from: NodeId, to: NodeId)

pub fn connect_exit(&mut self, fragment: Fragment, to: NodeId)

pub fn matcher_fragment(&mut self, matcher: BuildMatcher<'src>) -> Fragment

pub fn epsilon_fragment(&mut self) -> Fragment

pub fn sequence(&mut self, fragments: &[Fragment]) -> Fragment

Connect fragments in sequence: f1 → f2 → … → fn

pub fn alternation(&mut self, fragments: &[Fragment]) -> Fragment

Connect fragments in parallel (alternation): entry → [f1|f2|…|fn] → exit

pub fn zero_or_more(&mut self, inner: Fragment, nav: Nav) -> Fragment

Zero or more (greedy): inner*

pub fn zero_or_more_lazy(&mut self, inner: Fragment, nav: Nav) -> Fragment

Zero or more (non-greedy): inner*?

pub fn one_or_more(&mut self, inner: Fragment, nav: Nav) -> Fragment

One or more (greedy): inner+

pub fn one_or_more_lazy(&mut self, inner: Fragment, nav: Nav) -> Fragment

One or more (non-greedy): inner+?

pub fn optional(&mut self, inner: Fragment) -> Fragment

Optional (greedy): inner?

pub fn optional_lazy(&mut self, inner: Fragment) -> Fragment

Optional (non-greedy): inner??

pub fn zero_or_more_array(&mut self, inner: Fragment, nav: Nav) -> Fragment

Zero or more with array collection (greedy): inner*

pub fn zero_or_more_array_lazy(&mut self, inner: Fragment, nav: Nav) -> Fragment

Zero or more with array collection (non-greedy): inner*?

pub fn one_or_more_array(&mut self, inner: Fragment, nav: Nav) -> Fragment

One or more with array collection (greedy): inner+

pub fn one_or_more_array_lazy(&mut self, inner: Fragment, nav: Nav) -> Fragment

One or more with array collection (non-greedy): inner+?

pub fn zero_or_more_array_qis(&mut self, inner: Fragment, nav: Nav) -> Fragment

Zero or more with QIS object wrapping (greedy): inner*

Each iteration is wrapped in StartObject/EndObject to keep multiple captures coupled per-iteration.

pub fn zero_or_more_array_qis_lazy( &mut self, inner: Fragment, nav: Nav, ) -> Fragment

Zero or more with QIS object wrapping (non-greedy): inner*?

pub fn one_or_more_array_qis(&mut self, inner: Fragment, nav: Nav) -> Fragment

One or more with QIS object wrapping (greedy): inner+

pub fn one_or_more_array_qis_lazy( &mut self, inner: Fragment, nav: Nav, ) -> Fragment

One or more with QIS object wrapping (non-greedy): inner+?

pub fn optional_qis(&mut self, inner: Fragment) -> Fragment

Optional with QIS object wrapping: inner?

Wraps the optional value in an object scope.

pub fn optional_qis_lazy(&mut self, inner: Fragment) -> Fragment

Optional with QIS object wrapping (non-greedy): inner??

pub fn wrap_definitions_with_root(&mut self, root_kind: &'src str)

Wrap definitions that don’t already match the root node kind.

For each definition whose entry matcher doesn’t match root_kind, prepends a transition that matches the root and descends into children. This allows queries like (function_declaration) to work when the interpreter starts at tree root (e.g., program).

Source

impl<'src> BuildGraph<'src>

pub fn printer(&self) -> GraphPrinter<'_, 'src>

pub fn dump(&self) -> String

pub fn dump_with_dead(&self, dead_nodes: &HashSet<NodeId>) -> String

pub fn dump_live(&self, dead_nodes: &HashSet<NodeId>) -> String