pub struct DiagnosticBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> DiagnosticBuilder<'a>
impl<'a> DiagnosticBuilder<'a>
Sourcepub fn message(self, msg: impl Into<String>) -> Self
pub fn message(self, msg: impl Into<String>) -> Self
Provide custom detail for this diagnostic, rendered using the kind’s template.
Sourcepub fn suppression_range(self, range: TextRange) -> Self
pub fn suppression_range(self, range: TextRange) -> Self
Set the suppression range for this diagnostic.
The suppression range is used to suppress cascading errors. Errors whose display range falls within another error’s suppression range may be suppressed if the containing error has higher priority.
Typically set to the parent context span (e.g., enclosing tree).